pub struct Sink { /* private fields */ }Expand description
A push-only sink for recorded introspections, delayed errors, warnings, and traced values.
All tracked methods of this type are of the form (&mut self, ..) -> (), so
in principle they do not need validation (though that optimization is not
yet implemented in comemo).
Implementations
Sourceimpl Sink
impl Sink
Sourcepub const MAX_VALUES: usize = 10
pub const MAX_VALUES: usize = 10
The maximum number of traced values.
Sourcepub fn introspections(&self) -> &[Introspection]
pub fn introspections(&self) -> &[Introspection]
Get the introspections.
Sourcepub fn delayed(&mut self) -> EcoVec<SourceDiagnostic>
pub fn delayed(&mut self) -> EcoVec<SourceDiagnostic>
Get the stored delayed errors.
Sourcepub fn warnings(self) -> EcoVec<SourceDiagnostic>
pub fn warnings(self) -> EcoVec<SourceDiagnostic>
Get the stored warnings.
Sourcepub fn extend_from_sink(&mut self, other: Sink)
pub fn extend_from_sink(&mut self, other: Sink)
Extend from another sink.
Sourceimpl Sink
impl Sink
Sourcepub fn introspection(&mut self, introspection: Introspection)
pub fn introspection(&mut self, introspection: Introspection)
Trace an introspection.
Sourcepub fn delayed_error(&mut self, error: SourceDiagnostic)
pub fn delayed_error(&mut self, error: SourceDiagnostic)
Add a delayed error.
Sourcepub fn delayed_errors(&mut self, errors: EcoVec<SourceDiagnostic>)
pub fn delayed_errors(&mut self, errors: EcoVec<SourceDiagnostic>)
Add multiple delayed errors.
Sourcepub fn warn(&mut self, warning: SourceDiagnostic)
pub fn warn(&mut self, warning: SourceDiagnostic)
Add a warning.