pub enum PathOrStr {
Path(RootedPath),
Str(Str),
}Expand description
A string or a path.
This type is commonly accepted by functions that read from a path.
Variants
Path(RootedPath)
Str(Str)
Implementations
Sourceimpl PathOrStr
impl PathOrStr
Sourcepub fn resolve(&self, within: FileId) -> HintedStrResult<RootedPath>
pub fn resolve(&self, within: FileId) -> HintedStrResult<RootedPath>
Resolves this path or string relative to the file that resides at
within.
The path string may be absolute or relative. If relative, it’s resolved
relative to the parent directory of within (which should point to a
file rather than a directory).
Sourcepub fn resolve_if_some(
&self,
within: Option<FileId>,
) -> HintedStrResult<RootedPath>
pub fn resolve_if_some( &self, within: Option<FileId>, ) -> HintedStrResult<RootedPath>
Resolves the path if within is Some(_) or returns
an error that the file system could not be accessed, otherwise.