pub enum Selector {
Elem(Element, Option<SmallVec<[(u8, Value); 1]>>),
Location(Location),
Label(Label),
Regex(Regex),
Can(TypeId),
Or(EcoVec<Self>),
And(EcoVec<Self>),
Before {
selector: Arc<Self>,
end: Arc<Self>,
inclusive: bool,
},
After {
selector: Arc<Self>,
start: Arc<Self>,
inclusive: bool,
},
Within {
selector: Arc<Self>,
ancestor: Arc<Self>,
},
}Expand description
A filter for selecting elements within the document.
Variants
Elem(Element, Option<SmallVec<[(u8, Value); 1]>>)
Matches a specific type of element.
If there is a dictionary, only elements with the fields from the dictionary match.
Location(Location)
Matches the element at the specified location.
Label(Label)
Matches elements with a specific label.
Regex(Regex)
Matches text elements through a regular expression.
Can(TypeId)
Matches elements with a specific capability.
This is not exposed, but used internally.
Or(EcoVec<Self>)
Matches if any of the subselectors match.
And(EcoVec<Self>)
Matches if all of the subselectors match.
Before
Matches all matches of selector before end.
After
Matches all matches of selector after start.
Within
Matches all matches of selector that are strictly within ancestor.
This is not yet exposed, but used internally.
Implementations
Sourceimpl Selector
impl Selector
Sourcepub fn can<T: ?Sized + Any>() -> Self
pub fn can<T: ?Sized + Any>() -> Self
Define a simple Selector::Can selector.
Sourceimpl Selector
impl Selector
Sourcepub fn or(self, others: Vec<Selector>) -> Selector
pub fn or(self, others: Vec<Selector>) -> Selector
Selects all elements that match this or any of the other selectors.
Sourcepub fn and(self, others: Vec<Selector>) -> Selector
pub fn and(self, others: Vec<Selector>) -> Selector
Selects all elements that match this and all of the other selectors.
Sourcepub fn before(self, end: LocatableSelector, inclusive: bool) -> Selector
pub fn before(self, end: LocatableSelector, inclusive: bool) -> Selector
Returns a modified selector that will only match elements that occur before the first match of end.
Sourcepub fn after(self, start: LocatableSelector, inclusive: bool) -> Selector
pub fn after(self, start: LocatableSelector, inclusive: bool) -> Selector
Returns a modified selector that will only match elements that occur after the first match of start.
Sourcepub fn within(self, ancestor: LocatableSelector) -> Selector
pub fn within(self, ancestor: LocatableSelector) -> Selector
Returns a modified selector that will only match elements that are contained within any elements matching the ancestor selector.