pub struct Array(/* private fields */);Expand description
A sequence of values.
Implementations
Sourceimpl Array
impl Array
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a new vec, with a known capacity.
Sourcepub fn first_mut(&mut self) -> StrResult<&mut Value>
pub fn first_mut(&mut self) -> StrResult<&mut Value>
Mutably borrow the first value in the array.
Sourcepub fn last_mut(&mut self) -> StrResult<&mut Value>
pub fn last_mut(&mut self) -> StrResult<&mut Value>
Mutably borrow the last value in the array.
Sourceimpl Array
impl Array
Sourcepub fn first(&self, default: Option<Value>) -> StrResult<Value>
pub fn first(&self, default: Option<Value>) -> StrResult<Value>
Returns the first item in the array.
Sourcepub fn last(&self, default: Option<Value>) -> StrResult<Value>
pub fn last(&self, default: Option<Value>) -> StrResult<Value>
Returns the last item in the array.
Sourcepub fn at(&self, index: i64, default: Option<Value>) -> StrResult<Value>
pub fn at(&self, index: i64, default: Option<Value>) -> StrResult<Value>
Returns the item at the specified index in the array.
Sourcepub fn insert(&mut self, index: i64, value: Value) -> StrResult<()>
pub fn insert(&mut self, index: i64, value: Value) -> StrResult<()>
Inserts a value into the array at the specified index, shifting all subsequent elements to the right.
Sourcepub fn remove(&mut self, index: i64, default: Option<Value>) -> StrResult<Value>
pub fn remove(&mut self, index: i64, default: Option<Value>) -> StrResult<Value>
Removes the value at the specified index from the array and return it.
Sourcepub fn slice(
&self,
start: i64,
end: Option<i64>,
count: Option<i64>,
) -> StrResult<Array>
pub fn slice( &self, start: i64, end: Option<i64>, count: Option<i64>, ) -> StrResult<Array>
Extracts a subslice of the array.
Sourcepub fn find(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
searcher: Func,
) -> SourceResult<Option<Value>>
pub fn find( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, searcher: Func, ) -> SourceResult<Option<Value>>
Searches for an item for which the given function returns {true} and returns the first match or {none} if there is no match.
Sourcepub fn position(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
searcher: Func,
) -> SourceResult<Option<i64>>
pub fn position( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, searcher: Func, ) -> SourceResult<Option<i64>>
Searches for an item for which the given function returns {true} and returns the index of the first match or {none} if there is no match.
Sourcepub fn range(
args: &mut Args,
inclusive: bool,
step: NonZeroI64,
) -> SourceResult<Array>
pub fn range( args: &mut Args, inclusive: bool, step: NonZeroI64, ) -> SourceResult<Array>
Create an array consisting of a sequence of numbers.
Sourcepub fn filter(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
test: Func,
) -> SourceResult<Array>
pub fn filter( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, test: Func, ) -> SourceResult<Array>
Produces a new array with only the items from the original one for which the given function returns {true}.
Sourcepub fn map(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
mapper: Func,
) -> SourceResult<Array>
pub fn map( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, mapper: Func, ) -> SourceResult<Array>
Produces a new array in which all items from the original one were transformed with the given function.
Sourcepub fn enumerate(self, start: i64) -> StrResult<Array>
pub fn enumerate(self, start: i64) -> StrResult<Array>
Returns a new array with the values alongside their indices.
Sourcepub fn zip(self, args: &mut Args, exact: bool) -> SourceResult<Array>
pub fn zip(self, args: &mut Args, exact: bool) -> SourceResult<Array>
Zips the array with other arrays.
Sourcepub fn fold(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
init: Value,
folder: Func,
) -> SourceResult<Value>
pub fn fold( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, init: Value, folder: Func, ) -> SourceResult<Value>
Folds all items into a single value using an accumulator function.
Sourcepub fn sum(self, default: Option<Value>) -> HintedStrResult<Value>
pub fn sum(self, default: Option<Value>) -> HintedStrResult<Value>
Sums all items (works for all types that can be added).
Sourcepub fn product(self, default: Option<Value>) -> HintedStrResult<Value>
pub fn product(self, default: Option<Value>) -> HintedStrResult<Value>
Calculates the product of all items (works for all types that can be multiplied).
Sourcepub fn any(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
test: Func,
) -> SourceResult<bool>
pub fn any( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, test: Func, ) -> SourceResult<bool>
Whether the given function returns {true} for any item in the array.
Sourcepub fn all(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
test: Func,
) -> SourceResult<bool>
pub fn all( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, test: Func, ) -> SourceResult<bool>
Whether the given function returns {true} for all items in the array.
Sourcepub fn join(
self,
separator: Option<Value>,
last: Option<Value>,
default: Option<Value>,
) -> StrResult<Value>
pub fn join( self, separator: Option<Value>, last: Option<Value>, default: Option<Value>, ) -> StrResult<Value>
Combine all items in the array into one.
Sourcepub fn intersperse(self, separator: Value) -> Array
pub fn intersperse(self, separator: Value) -> Array
Returns an array with a copy of the separator value placed between adjacent elements.
Sourcepub fn chunks(self, chunk_size: NonZeroUsize, exact: bool) -> Array
pub fn chunks(self, chunk_size: NonZeroUsize, exact: bool) -> Array
Splits an array into non-overlapping chunks, starting at the beginning, ending with a single remainder chunk.
Sourcepub fn windows(self, window_size: NonZeroUsize) -> Array
pub fn windows(self, window_size: NonZeroUsize) -> Array
Returns sliding windows of window-size elements over an array.
Sourcepub fn sorted(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
span: Span,
key: Option<Func>,
by: Option<Func>,
) -> SourceResult<Array>
pub fn sorted( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, span: Span, key: Option<Func>, by: Option<Func>, ) -> SourceResult<Array>
Return a sorted version of this array, optionally by a given key function.