pub struct Decimal(/* private fields */);Expand description
A fixed-point decimal number type.
Implementations
Sourceimpl Decimal
impl Decimal
pub const ZERO: Self
pub const ONE: Self
pub const MIN: Self
pub const MAX: Self
Sourcepub const fn is_negative(self) -> bool
pub const fn is_negative(self) -> bool
Whether this decimal value is negative.
Sourcepub fn is_integer(self) -> bool
pub fn is_integer(self) -> bool
Whether this decimal has fractional part equal to zero (is an integer).
Sourcepub fn floor(self) -> Self
pub fn floor(self) -> Self
Computes the largest integer less than or equal to this decimal.
A decimal is returned as this may not be within i64’s range of
values.
Sourcepub fn ceil(self) -> Self
pub fn ceil(self) -> Self
Computes the smallest integer greater than or equal to this decimal.
A decimal is returned as this may not be within i64’s range of
values.
Sourcepub fn fract(self) -> Self
pub fn fract(self) -> Self
Returns the fractional part of this decimal (with the integer part set to zero).
Sourcepub fn round(self, digits: i32) -> Option<Self>
pub fn round(self, digits: i32) -> Option<Self>
Rounds this decimal up to the specified amount of digits with the traditional rounding rules, using the “midpoint away from zero” strategy (6.5 -> 7, -6.5 -> -7).
If given a negative amount of digits, rounds to integer digits instead with the same rounding strategy. For example, rounding to -3 digits will turn 34567.89 into 35000.00 and -34567.89 into -35000.00.
Note that this can return None when using negative digits where the
rounded number would overflow the available range for decimals.
Sourcepub fn checked_add(self, other: Self) -> Option<Self>
pub fn checked_add(self, other: Self) -> Option<Self>
Attempts to add two decimals.
Returns None on overflow or underflow.
Sourcepub fn checked_sub(self, other: Self) -> Option<Self>
pub fn checked_sub(self, other: Self) -> Option<Self>
Attempts to subtract a decimal from another.
Returns None on overflow or underflow.
Sourcepub fn checked_mul(self, other: Self) -> Option<Self>
pub fn checked_mul(self, other: Self) -> Option<Self>
Attempts to multiply two decimals.
Returns None on overflow or underflow.
Sourcepub fn checked_div(self, other: Self) -> Option<Self>
pub fn checked_div(self, other: Self) -> Option<Self>
Attempts to divide two decimals.
Returns None if other is zero, as well as on overflow or underflow.
Sourcepub fn checked_div_euclid(self, other: Self) -> Option<Self>
pub fn checked_div_euclid(self, other: Self) -> Option<Self>
Attempts to obtain the quotient of Euclidean division between two
decimals. Implemented similarly to f64::div_euclid.
The returned quotient is truncated and adjusted if the remainder was negative.
Returns None if other is zero, as well as on overflow or underflow.
Sourcepub fn checked_rem_euclid(self, other: Self) -> Option<Self>
pub fn checked_rem_euclid(self, other: Self) -> Option<Self>
Attempts to obtain the remainder of Euclidean division between two
decimals. Implemented similarly to f64::rem_euclid.
The returned decimal r is non-negative within the range
0.0 <= r < other.abs().
Returns None if other is zero, as well as on overflow or underflow.
Sourcepub fn checked_rem(self, other: Self) -> Option<Self>
pub fn checked_rem(self, other: Self) -> Option<Self>
Attempts to calculate the remainder of the division of two decimals.
Returns None if other is zero, as well as on overflow or underflow.
Sourcepub fn checked_powi(self, other: i64) -> Option<Self>
pub fn checked_powi(self, other: i64) -> Option<Self>
Attempts to take one decimal to the power of an integer.
Returns None for invalid operands, as well as on overflow or
underflow.