Dict

Struct Dict 

pub struct Dict(/* private fields */);
A map from string keys to values.

Implementations

Source

impl Dict

pub fn new() -> Self

Create a new, empty dictionary.

pub fn is_empty(&self) -> bool

Whether the dictionary is empty.

pub fn get(&self, key: &str) -> StrResult<&Value>

Borrow the value at the given key.

pub fn at_mut(&mut self, key: &str) -> HintedStrResult<&mut Value>

Mutably borrow the value the given key maps to.

pub fn take(&mut self, key: &str) -> StrResult<Value>

Remove the value if the dictionary contains the given key.

pub fn contains(&self, key: &str) -> bool

Whether the dictionary contains a specific key.

pub fn clear(&mut self)

Clear the dictionary.

pub fn iter(&self) -> Iter<'_, Str, Value>

Iterate over pairs of references to the contained keys and values.

pub fn finish(&self, expected: &[&str]) -> StrResult<()>

Check if there is any remaining pair, and if so return an “unexpected key” error.

pub fn unexpected_keys( unexpected: Vec<&str>, hint_expected: Option<&[&str]>, ) -> EcoString

Source

impl Dict

pub fn construct(value: ToDict) -> Dict

Converts a value into a dictionary.

pub fn len(&self) -> usize

The number of pairs in the dictionary.

pub fn at(&self, key: Str, default: Option<Value>) -> StrResult<Value>

Returns the value associated with the specified key in the dictionary.

pub fn insert(&mut self, key: Str, value: Value)

Inserts a new pair into the dictionary.

pub fn remove(&mut self, key: Str, default: Option<Value>) -> StrResult<Value>

Removes a pair from the dictionary by key and return the value.

pub fn keys(&self) -> Array

Returns the keys of the dictionary as an array in insertion order.

pub fn values(&self) -> Array

Returns the values of the dictionary as an array in insertion order.

pub fn pairs(&self) -> Array

Returns the keys and values of the dictionary as an array of pairs.

pub fn filter( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, test: Func, ) -> SourceResult<Dict>

Produces a new dictionary with only the pairs from the original one for which the given function returns {true}.

pub fn map( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, mapper: Func, ) -> SourceResult<Dict>

Produces a new dictionary where the keys are the same, but the values are transformed with the given function.