pub struct Func { /* private fields */ }Expand description
A mapping from argument values to a return value.
Implementations
Sourceimpl Func
impl Func
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
The function’s name (e.g. min).
Returns None if this is an anonymous closure.
Sourcepub fn title(&self) -> Option<&'static str>
pub fn title(&self) -> Option<&'static str>
The function’s title case name, for use in documentation (e.g. Minimum).
Returns None if this is a closure.
Sourcepub fn contextual(&self) -> Option<bool>
pub fn contextual(&self) -> Option<bool>
Whether the function is known to be contextual.
Sourcepub fn params(&self) -> impl Iterator<Item = ParamInfo>
pub fn params(&self) -> impl Iterator<Item = ParamInfo>
Get details about this function’s parameters if available.
Sourcepub fn param(&self, name: &str) -> Option<ParamInfo>
pub fn param(&self, name: &str) -> Option<ParamInfo>
Get the parameter info for a parameter with the given name if it exist.
Sourcepub fn returns(&self) -> Option<&'static CastInfo>
pub fn returns(&self) -> Option<&'static CastInfo>
Get details about the function’s return type.
Sourcepub fn def_site(&self) -> Option<DefSite>
pub fn def_site(&self) -> Option<DefSite>
Where the function is defined in the Rust source code (only Some(_) if
it is native, and even then it can be None if the function is
generated, like the typed HTML API).
Sourcepub fn scope(&self) -> Option<&'static Scope>
pub fn scope(&self) -> Option<&'static Scope>
The function’s associated scope of sub-definition.
Sourcepub fn field(
&self,
field: &str,
sink: impl WarningSink,
) -> StrResult<&'static Value>
pub fn field( &self, field: &str, sink: impl WarningSink, ) -> StrResult<&'static Value>
Get a field from this function’s scope, if possible.
Sourcepub fn to_element(&self) -> Option<Element>
pub fn to_element(&self) -> Option<Element>
Extract the element function, if it is one.
Sourcepub fn to_plugin(&self) -> Option<&PluginFunc>
pub fn to_plugin(&self) -> Option<&PluginFunc>
Extract the plugin function, if it is one.