pub struct NativeParamInfo {
pub name: &'static str,
pub docs: &'static str,
pub def_site: Option<DefSite>,
pub input: CastInfo,
pub default: Option<fn() -> Value>,
pub positional: bool,
pub named: bool,
pub variadic: bool,
pub required: bool,
pub settable: bool,
}Expand description
Describes a function parameter.
Fields
name: &'static strThe parameter’s name.
docs: &'static strDocumentation for the parameter.
def_site: Option<DefSite>Where the parameter is defined in the source code.
input: CastInfoDescribe what values this parameter accepts.
default: Option<fn() -> Value>Creates an instance of the parameter’s default value.
positional: boolIs the parameter positional?
named: boolIs the parameter named?
Can be true even if positional is true if the parameter can be given
in both variants.
variadic: boolCan the parameter be given any number of times?
required: boolIs the parameter required?
settable: boolIs the parameter settable with a set rule?