pub struct NativeTypeData {
pub name: &'static str,
pub long_name: &'static str,
pub title: &'static str,
pub docs: &'static str,
pub def_site: DefSite,
pub keywords: &'static [&'static str],
pub constructor: LazyLock<Option<&'static NativeFuncData>>,
pub scope: LazyLock<Scope>,
}Expand description
Defines a native type.
Fields
name: &'static strThe type’s normal name (e.g. str), as exposed to Typst.
long_name: &'static strThe type’s long name (e.g. string), for error messages.
title: &'static strThe function’s title case name (e.g. String).
docs: &'static strThe documentation for this type as a string.
def_site: DefSiteWhere the function is defined in the source code.
keywords: &'static [&'static str]A list of alternate search terms for this type.
constructor: LazyLock<Option<&'static NativeFuncData>>The constructor for this type.
scope: LazyLock<Scope>Definitions in the scope of the type.