pub struct Type(/* private fields */);Expand description
Describes a kind of value.
Implementations
Sourceimpl Type
impl Type
Sourcepub fn of<T: NativeType>() -> Self
pub fn of<T: NativeType>() -> Self
Get the type for T.
Sourcepub fn short_name(&self) -> &'static str
pub fn short_name(&self) -> &'static str
The type’s short name, how it is used in code (e.g. str).
Sourcepub fn long_name(&self) -> &'static str
pub fn long_name(&self) -> &'static str
The type’s long name, for use in diagnostics (e.g. string).
Sourcepub fn title(&self) -> &'static str
pub fn title(&self) -> &'static str
The type’s title case name, for use in documentation (e.g. String).
Sourcepub fn constructor(&self) -> StrResult<Func>
pub fn constructor(&self) -> StrResult<Func>
This type’s constructor function.