Chainable

Trait Chainable 

pub trait Chainable {
    // Required method
    fn chain<'a>(&'a self, outer: &'a StyleChain<'_>) -> StyleChain<'a>;
}
Things that can be attached to a style chain.

Required Methods

fn chain<'a>(&'a self, outer: &'a StyleChain<'_>) -> StyleChain<'a>

Attach self as the first link of the chain.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Chainable for LazyHash<Style>

Source

fn chain<'a>(&'a self, outer: &'a StyleChain<'_>) -> StyleChain<'a>

Source

impl Chainable for [LazyHash<Style>]

Source

fn chain<'a>(&'a self, outer: &'a StyleChain<'_>) -> StyleChain<'a>

Source

impl<const N: usize> Chainable for [LazyHash<Style>; N]

Source

fn chain<'a>(&'a self, outer: &'a StyleChain<'_>) -> StyleChain<'a>

Implementors