pub enum DocumentPosition {
Paged(PagedPosition),
Html(HtmlPosition),
}Expand description
Physical position in a document, be it paged or HTML.
This type exists to make it possible to write functions that are generic over the document target.
Variants
Paged(PagedPosition)
If the document is paged, the position is expressed as coordinates inside of a page.
Html(HtmlPosition)
If the document is an HTML document, the position points to a specific node in the DOM tree.
Implementations
Sourceimpl DocumentPosition
impl DocumentPosition
Sourcepub fn as_paged(self) -> Option<PagedPosition>
pub fn as_paged(self) -> Option<PagedPosition>
Returns the PagedPosition if this is one.
Sourcepub fn as_paged_or_default(self) -> PagedPosition
pub fn as_paged_or_default(self) -> PagedPosition
Returns the PagedPosition or a position at page 1, point (0, 0) if
this is not a paged position.
Sourcepub fn as_html(self) -> Option<HtmlPosition>
pub fn as_html(self) -> Option<HtmlPosition>
Returns the HtmlPosition if available.