pub struct ElementIntrospector<P> { /* private fields */ }Expand description
An underlying target-agnostic introspector used for most queries.
The parameter P represents a position type for the relevant target.
Implementations
Sourceimpl<P> ElementIntrospector<P>
impl<P> ElementIntrospector<P>
Sourcepub fn query_first(&self, selector: &Selector) -> Option<Content>
pub fn query_first(&self, selector: &Selector) -> Option<Content>
Queries for the first element that matches the selector.
Sourcepub fn query_unique(&self, selector: &Selector) -> StrResult<Content>
pub fn query_unique(&self, selector: &Selector) -> StrResult<Content>
Queries for the first element that matches the selector.
Sourcepub fn query_label(&self, label: Label) -> StrResult<&Content>
pub fn query_label(&self, label: Label) -> StrResult<&Content>
Queries for a unique element with the label.
Sourcepub fn query_labelled(&self) -> EcoVec<Content>
pub fn query_labelled(&self) -> EcoVec<Content>
Queries for all elements with a label.
Sourcepub fn query_count_before(&self, selector: &Selector, end: Location) -> usize
pub fn query_count_before(&self, selector: &Selector, end: Location) -> usize
An optimized version of query(selector.before(end, true).len() used by
counters and state.
Sourcepub fn label_count(&self, label: Label) -> usize
pub fn label_count(&self, label: Label) -> usize
Checks how many times a label exists.
Sourcepub fn locator(&self, key: u128, base: Location) -> Option<Location>
pub fn locator(&self, key: u128, base: Location) -> Option<Location>
Tries to find a location for an element with the given key hash
that is closest after the base.
Sourcepub fn position(&self, location: Location) -> Option<&P>
pub fn position(&self, location: Location) -> Option<&P>
Returns the target-specific position of the element at the given location.
Sourcepub fn get_by_idx(&self, idx: usize) -> &Content
pub fn get_by_idx(&self, idx: usize) -> &Content
Retrieves the element with the given index.
Sourcepub fn get_pos_by_idx(&self, idx: usize) -> &P
pub fn get_pos_by_idx(&self, idx: usize) -> &P
Retrieves the position of the element with the given index.
Sourcepub fn get_by_loc(&self, location: &Location) -> Option<&Content>
pub fn get_by_loc(&self, location: &Location) -> Option<&Content>
Retrieves an element by its location.
Sourcepub fn binary_search(
&self,
list: &[Content],
elem: &Content,
) -> Result<usize, usize>
pub fn binary_search( &self, list: &[Content], elem: &Content, ) -> Result<usize, usize>
Performs a binary search for elem among the list.
Sourcepub fn elem_index(&self, elem: &Content) -> usize
pub fn elem_index(&self, elem: &Content) -> usize
Gets the index of this element.