pub struct HtmlPosition { /* private fields */ }Expand description
A position in an HTML tree.
Implementations
Sourceimpl HtmlPosition
impl HtmlPosition
Sourcepub fn new(element: EcoVec<usize>) -> Self
pub fn new(element: EcoVec<usize>) -> Self
A position in an HTML document pointing to a specific node as a whole.
The items of the vector corresponds to indices that can be used to
traverse the DOM tree from the root to reach the node. In practice, this
means that the first item of the vector will often be 1 for the
<body> tag (0 being the <head> tag in a typical HTML document).
Consecutive text nodes in Typst’s HTML representation are grouped for the purpose of this indexing as the segmentation is not observable in the resulting DOM.
Sourcepub fn at_char(self, offset: usize) -> Self
pub fn at_char(self, offset: usize) -> Self
Specifies a character offset inside of the node, to build a position pointing to a specific point in text.
This only makes sense if the node is a text node, not an element or a frame.
The offset is expressed in codepoints, not in bytes, to be encoding-independent.
Sourcepub fn in_frame(self, point: Point) -> Self
pub fn in_frame(self, point: Point) -> Self
Specifies a point in a frame, to build a more precise position.
This only makes sense if the node is a frame.
Sourcepub fn details(&self) -> Option<&InnerHtmlPosition>
pub fn details(&self) -> Option<&InnerHtmlPosition>
Extra-information for a more precise location inside of the node
designated by HtmlPosition::element.
Sourcepub fn element(&self) -> impl Iterator<Item = usize>
pub fn element(&self) -> impl Iterator<Item = usize>
Indices for traversing an HTML tree to reach the node corresponding to this position.
See HtmlPosition::new for more details.