pub struct PositionIntrospection(pub Location, pub Span);Expand description
Retrieves the exact position of an element in the document.
Tuple Fields
0: Location1: SpanTrait Implementations
Sourceimpl Clone for PositionIntrospection
impl Clone for PositionIntrospection
Sourcefn clone(&self) -> PositionIntrospection
fn clone(&self) -> PositionIntrospection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PositionIntrospection
impl Debug for PositionIntrospection
Sourceimpl Hash for PositionIntrospection
impl Hash for PositionIntrospection
Sourceimpl Introspect for PositionIntrospection
impl Introspect for PositionIntrospection
Sourcetype Output = PagedPosition
type Output = PagedPosition
The kind of output the introspection produces. This is what should
stabilize. Read more
Sourcefn introspect(
&self,
_: &mut Engine<'_>,
introspector: Tracked<'_, dyn Introspector + '_>,
) -> Self::Output
fn introspect( &self, _: &mut Engine<'_>, introspector: Tracked<'_, dyn Introspector + '_>, ) -> Self::Output
Resolves the output value. Read more
Sourceimpl PartialEq for PositionIntrospection
impl PartialEq for PositionIntrospection
Sourcefn eq(&self, other: &PositionIntrospection) -> bool
fn eq(&self, other: &PositionIntrospection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PositionIntrospection