pub struct QueryFirstIntrospection(pub Selector, pub Span);Expand description
Retrieves the first match of a selector in the document.
Tuple Fields
0: Selector1: SpanTrait Implementations
Sourceimpl Clone for QueryFirstIntrospection
impl Clone for QueryFirstIntrospection
Sourcefn clone(&self) -> QueryFirstIntrospection
fn clone(&self) -> QueryFirstIntrospection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryFirstIntrospection
impl Debug for QueryFirstIntrospection
Sourceimpl Hash for QueryFirstIntrospection
impl Hash for QueryFirstIntrospection
Sourceimpl Introspect for QueryFirstIntrospection
impl Introspect for QueryFirstIntrospection
Sourceimpl PartialEq for QueryFirstIntrospection
impl PartialEq for QueryFirstIntrospection
Sourcefn eq(&self, other: &QueryFirstIntrospection) -> bool
fn eq(&self, other: &QueryFirstIntrospection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for QueryFirstIntrospection