pub struct State { /* private fields */ }Expand description
Manages stateful parts of your document.
Implementations
Sourceimpl State
impl State
Sourcepub fn get(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
span: Span,
) -> SourceResult<Value>
pub fn get( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, span: Span, ) -> SourceResult<Value>
Retrieves the value of the state at the current location.
Sourcepub fn at(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
span: Span,
selector: LocatableSelector,
) -> SourceResult<Value>
pub fn at( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, span: Span, selector: LocatableSelector, ) -> SourceResult<Value>
Retrieves the value of the state at the given selector’s unique match.
Sourcepub fn final_(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
span: Span,
) -> SourceResult<Value>
pub fn final_( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, span: Span, ) -> SourceResult<Value>
Retrieves the value of the state at the end of the document.
Sourcepub fn update(self, span: Span, update: StateUpdate) -> Content
pub fn update(self, span: Span, update: StateUpdate) -> Content
Updates the value of the state.