Module math

Module math 

Mathematical formulas.

Re-exports

pub use self::accent::ACCENT_SHORT_FALL;
pub use self::accent::Accent;
pub use self::accent::AccentElem;

Modules

accent
ir
Intermediate representation for math.

Structs

AlignPointElem
A math alignment point: &, &&.
AttachElem
A base with optional attachments.
Augment
Parameters specifying how augmentation lines should be drawn on a matrix.
AugmentOffsets
The offsets at which augmentation lines should be drawn on a matrix.
BinomElem
A binomial expression.
CancelElem
Displays a diagonal line over a part of an equation.
CasesElem
A case distinction.
ClassElem
Forced use of a certain math class.
Delimiter
A delimiter is a single character that is used to delimit a matrix, vector or cases. The character has to be a Unicode codepoint tagged as a math “opening”, “closing” or “fence”.
DelimiterPair
A pair of delimiters (one closing, one opening) used for matrices, vectors and cases.
EquationElem
A mathematical equation.
FracElem
A mathematical fraction.
LimitsElem
Forces a base to display attachments as limits.
LrElem
Scales delimiters.
MatElem
A matrix.
MidElem
Scales delimiters vertically to the nearest surrounding {lr()} group.
OpElem
A text operator in an equation.
OverbraceElem
A horizontal brace over content, with an optional annotation above.
OverbracketElem
A horizontal bracket over content, with an optional annotation above.
OverlineElem
A horizontal line over content.
OverparenElem
A horizontal parenthesis over content, with an optional annotation above.
OvershellElem
A horizontal tortoise shell bracket over content, with an optional annotation above.
PrimesElem
Grouped primes.
RootElem
A general root.
ScriptsElem
Forces a base to display attachments as scripts.
StretchElem
Stretches a glyph.
UnderbraceElem
A horizontal brace under content, with an optional annotation below.
UnderbracketElem
A horizontal bracket under content, with an optional annotation below.
UnderlineElem
A horizontal line under content.
UnderparenElem
A horizontal parenthesis under content, with an optional annotation below.
UndershellElem
A horizontal tortoise shell bracket under content, with an optional annotation below.
VecElem
A column vector.

Enums

CancelAngle
Defines the cancel line.
FracStyle
Fraction style
LeftRightAlternator
An iterator that alternates between the Left and Right values, if the initial value is not None.
Limits
Describes in which situation a frame should use limits for attachments.
MathSize
The size of elements in an equation.

Constants

DELIM_SHORT_FALL
How much less high scaled delimiters can be than what they wrap.
FRAC_PADDING
How much padding to add around each side of a fraction.
MEDIUM
QUAD
THICK
THIN
WIDE

Traits

Mathy
Trait for recognizing math elements and auto-wrapping them in equations.

Functions

abs
Takes the absolute value of an expression.
bb
Blackboard bold (double-struck) font style in math.
bold
Bold font style in math.
cal
Calligraphic (chancery) font style in math.
ceil
Ceils an expression.
display
Forced display style in math.
families
Resolve a prioritized iterator over the font families for math.
floor
Floors an expression.
frak
Fraktur font style in math.
get_lr_wrapper_func
Gets the Left/Right wrapper function corresponding to a symbol value, if any.
inline
Forced inline (text) style in math.
italic
Italic font style in math.
module
Create a module with all math definitions.
mono
Monospace font style in math.
norm
Takes the norm of an expression.
round
Rounds an expression.
sans
Sans-serif font style in math.
scr
Script (roundhand) font style in math.
script
Forced script style in math.
serif
Serif (roman) font style in math.
sqrt
A square root.
sscript
Forced second script style in math.
style_cramped
Styles something as cramped.
style_dtls
Sets dtls OpenType feature.
style_flac
Sets flac OpenType feature.
style_for_denominator
The style for denominators in the current style.
style_for_numerator
The style for numerators in the current style.
style_for_subscript
The style for subscripts in the current style.
style_for_superscript
The style for superscripts in the current style.
upright
Upright (non-italic) font style in math.