pub enum Limits {
Never,
Display,
Always,
}Expand description
Describes in which situation a frame should use limits for attachments.
Variants
Implementations
Sourceimpl Limits
impl Limits
Sourcepub fn for_char(c: char) -> Self
pub fn for_char(c: char) -> Self
The default limit configuration if the given character is the base.
Sourcepub fn for_char_with_class(c: char, class: Option<MathClass>) -> Self
pub fn for_char_with_class(c: char, class: Option<MathClass>) -> Self
The default limit configuration for a character with a known default class.
Sourcepub fn active(&self, styles: StyleChain<'_>) -> bool
pub fn active(&self, styles: StyleChain<'_>) -> bool
Whether limits should be displayed in this context.