FencedBody

Enum FencedBody 

pub enum FencedBody<'a> {
    Owned(MathItem<'a>),
    Shared {
        index: usize,
        sizing: Rc<SharedFenceSizing<'a>>,
    },
}
The body of a FencedItem.

Variants



Owned(MathItem<'a>)

Owned body.



Shared

Shared body stored in SharedFenceSizing.

Fields

index: usize
sizing: Rc<SharedFenceSizing<'a>>

Implementations

Source

impl<'a> FencedBody<'a>

pub fn sizing(&self) -> Option<&SharedFenceSizing<'a>>

Shared sizing info for split fence segments.

Methods from Deref<Target = MathItem<'a>>

pub fn is_ignorant(&self) -> bool

Whether this item should be ignored for spacing calculations.

pub fn span(&self) -> Span

Returns the source span of this item.

pub fn styles(&self) -> Option<StyleChain<'a>>

Returns the style chain of this item, if it is a component.

pub fn mid_stretched(&self) -> Option<bool>

Returns whether this glyph has been stretched as a middle delimiter.

pub fn is_multiline(&self) -> bool

Whether this item is a multiline item.

pub fn as_slice(&self) -> &[MathItem<'a>]

Returns the inner items if this is a group, or a slice containing just this item otherwise.

pub fn set_stretch_relative_to(&self, relative_to: Abs, axis: Axis)

Sets the reference size for relative stretching on the given axis.

pub fn set_stretch_font_size(&self, font_size: Abs, axis: Axis)

Sets the font size to use for short-fall calculations on the given axis.

pub fn set_flac(&self)

Enables the flac OpenType feature for this glyph.