pub struct MathProperties {
pub class: Option<MathClass>,
pub size: MathSize,
pub cramped: bool,
pub lspace: Option<Em>,
pub rspace: Option<Em>,
pub align_form_infix: bool,
pub span: Span,
/* private fields */
}Expand description
Shared properties for all layoutable math components.
Fields
class: Option<MathClass>The math class.
size: MathSizeThe current math size.
cramped: boolWhether this item is in a cramped style.
lspace: Option<Em>The amount of spacing to the left of this item.
rspace: Option<Em>The amount of spacing to the right of this item.
align_form_infix: boolWhether this item is at the start of a left-aligned column but semantically infix.
span: SpanThe source span.
Implementations
Sourceimpl MathProperties
impl MathProperties
Sourcepub fn default(styles: StyleChain<'_>, span: Span) -> MathProperties
pub fn default(styles: StyleChain<'_>, span: Span) -> MathProperties
Creates default properties from the given styles.
This gets the math size from the styles.