Module model

Module model 

Structuring elements that define the document model.

Structs

AnchorGenerator
Creates unique IDs for elements.
AssetData
The raw data for an asset.
AssetElem
Adds a custom file to a bundle.
Author
A list of authors.
Bibliography
A loaded bibliography.
BibliographyElem
A bibliography / reference listing.
CiteElem
Cite a work from the bibliography.
CiteGroup
A group of consecutive citations.
CslIndentElem
Translation of display="indent" in CSL.
CslLightElem
Translation of font-weight="light" in CSL.
CslStyle
A loaded CSL style.
DirectLinkElem
This is a temporary hack to dispatch to - a raw link that does not go through LinkElem in paged - LinkElem in HTML (there is no equivalent to a direct link)
DividerElem
A thematic break that separates sections of content.
DocumentElem
Manages metadata and is used to add a document file to a bundle.
DocumentInfo
Details about the document.
EarlyLinkResolver
Resolves location links during compilation.
Email
EmphElem
Emphasizes content by toggling italics.
EnumElem
A numbered list.
EnumItem
An enumeration item.
FigureCaption
The caption of a figure.
FigureElem
A figure with an optional caption.
FirstLineIndent
Configuration for first line indent.
FootnoteContainer
In HTML export, this is inserted at the end of the body to display footnotes.
FootnoteElem
A footnote.
FootnoteEntry
An entry in a footnote list.
FootnoteMarker
This is an empty element inserted by the HTML footnote rule to indicate the presence of the default footnote rule.
HeadingElem
A section heading.
JustificationLimits
Configures how justification may distribute spacing.
Keywords
A list of keywords.
LateLinkResolver
Resolves location links during export.
Limits
Determines the minimum and maximum size by or to which spacing may be shrunk and stretched.
LinkElem
Links to a URL or a location in the document.
LinkMarker
An element that wraps all content that is @Content::linked to a destination.
ListElem
A bullet list.
ListItem
A bullet list item.
NumberingPattern
How to turn a number into text.
OutlineElem
A table of contents, figures, or other elements.
OutlineEntry
Represents an entry line in an outline.
OutlineNode
A node in a tree of outline entry.
ParElem
A logical subdivison of textual content.
ParLine
A paragraph line.
ParLineMarker
A marker used to indicate the presence of a line.
ParbreakElem
A paragraph break.
QuoteElem
Displays a quote alongside an optional attribution.
RefElem
A reference to a label or bibliography.
RenderedBibliography
The rendered parts for a bibliography.
RenderedEntry
The rendered parts for a bibliography entry.
StrongElem
Strongly emphasizes content by increasing the font weight.
TableCell
A cell in the table.
TableElem
A table of items.
TableFooter
A repeatable table footer.
TableHLine
A horizontal line in the table.
TableHeader
A repeatable table header.
TableVLine
A vertical line in the table.
Telephone
TermItem
A term list item.
TermsElem
A list of terms and their descriptions.
TitleElem
A document title.
Url
A uniform resource locator with a maximum length.
Works
Fully formatted citations and references, generated once (through memoization) for the whole document. This setup is necessary because citation formatting is inherently stateful and we need access to all citations to do it. Fully formatted citation groups and bibliographies, generated once (through memoization) for the whole document.

Enums

Attribution
Attribution for a quote.
CitationForm
The form of the citation.
CslSource
Source for a CSL style.
Destination
A link destination.
DocumentFormat
Supported export formats for bundle documents.
FigureKind
The kind parameter of a FigureElem.
FootnoteBody
The body of a footnote can be either some content or a label referencing another footnote.
LineNumberingScope
Possible line numbering scope options, indicating how often the line number counter should be reset.
Linebreaks
How to determine line breaks in a paragraph.
LinkTarget
A target where a link can go.
ListMarker
A list’s marker.
Numbering
How to number a sequence of things.
OutlineIndent
Defines how an outline is indented.
PagedFormat
Supported paged export formats for bundle documents.
RefForm
The form of the reference.
ResolvedLink
A resolved internal link.
Supplement
Additional content for a reference.
TableChild
Any child of a table element.
TableItem
A table item, which is the basic unit of table specification.
UrlContactScheme

Constants

ASSET_UNSUPPORTED_RULE
DOCUMENT_UNSUPPORTED_RULE

Traits

Document
A document resulting from compilation.
Figurable
An element that can be auto-detected in a figure.
ListItemLike
A list item, enum item, or term list item.
ListLike
A list, enum, or term list.
Outlinable
Marks an element as being able to be outlined.
Refable
Marks an element as being able to be referenced. This is used to implement the @ref element.

Functions

define
Hook up all model definitions.
numbering
Applies a numbering to a sequence of numbers.