pub struct FootnoteElem {
pub numbering: Settable<Self, 0u8>,
pub body: FootnoteBody,
}Expand description
A footnote.
Fields
numbering: Settable<Self, 0u8>body: FootnoteBodyImplementations
Sourceimpl FootnoteElem
impl FootnoteElem
Sourcepub fn new(body: FootnoteBody) -> Self
pub fn new(body: FootnoteBody) -> Self
Create a new instance of the element.
Sourcepub fn with_numbering(self, numbering: Numbering) -> Self
pub fn with_numbering(self, numbering: Numbering) -> Self
Builder-style setter for the numbering field.
Sourceimpl FootnoteElem
impl FootnoteElem
Sourceimpl FootnoteElem
impl FootnoteElem
pub fn alt_text(styles: StyleChain<'_>, num: &str) -> EcoString
Sourcepub fn with_content(content: Content) -> Self
pub fn with_content(content: Content) -> Self
Creates a new footnote that the passed content as its body.
Sourcepub fn with_label(label: Label) -> Self
pub fn with_label(label: Label) -> Self
Creates a new footnote referencing the footnote with the specified label.
Sourcepub fn into_ref(&self, label: Label) -> Self
pub fn into_ref(&self, label: Label) -> Self
Creates a new footnote referencing the footnote with the specified label, with the other fields from the current footnote cloned.
Sourcepub fn body_content(&self) -> Option<&Content>
pub fn body_content(&self) -> Option<&Content>
Returns the content of the body of this footnote if it is not a ref.