pub struct LateLinkResolver<'a> { /* private fields */ }Expand description
Resolves location links during export.
This is used in paged exports. Compared to the EarlyLinkResolver, this
one can save an introspection iteration as links don’t need to be fully
resolved during compilation. Keeping the location link unresolved will also
be useful for tagging links in PDF 2.0 (linking to an element and not just a
position).
The downside is that links could be silently broken in a non-converging scenario where HTML would instead generate an error, so it’s a bit of a trade-off and not entirely clear whether this is the best way to do it.
Implementations
Sourceimpl<'a> LateLinkResolver<'a>
impl<'a> LateLinkResolver<'a>
Sourcepub fn new(
base: Option<&'a VirtualPath>,
introspector: &'a dyn Introspector,
) -> Self
pub fn new( base: Option<&'a VirtualPath>, introspector: &'a dyn Introspector, ) -> Self
Creates a resolver.
- In single-document export,
baseshould beNone. - In bundle export,
baseshould be the path of the document relative to which links shall be resolved.
Sourceimpl<'a> LateLinkResolver<'a>
Resolves a link to the given location.
impl<'a> LateLinkResolver<'a>
Resolves a link to the given location.
pub fn resolve(&self, location: Location) -> Option<ResolvedLink>