pub struct OutlineEntry {
pub level: NonZeroUsize,
pub element: Content,
pub fill: Settable<Self, 2u8>,
}Expand description
Represents an entry line in an outline.
Fields
level: NonZeroUsizeelement: Contentfill: Settable<Self, 2u8>Implementations
Sourceimpl OutlineEntry
impl OutlineEntry
Sourceimpl OutlineEntry
impl OutlineEntry
Sourceimpl OutlineEntry
impl OutlineEntry
Sourcepub fn indented(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
span: Span,
prefix: Option<Content>,
inner: Content,
gap: Length,
) -> SourceResult<Content>
pub fn indented( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, span: Span, prefix: Option<Content>, inner: Content, gap: Length, ) -> SourceResult<Content>
A helper function for producing an indented entry layout: Lays out a prefix and the rest of the entry in an indent-aware way.
Sourcepub fn prefix(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
span: Span,
) -> SourceResult<Option<Content>>
pub fn prefix( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, span: Span, ) -> SourceResult<Option<Content>>
Formats the element’s numbering (if any).
Sourcepub fn inner(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
span: Span,
) -> SourceResult<Content>
pub fn inner( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, span: Span, ) -> SourceResult<Content>
Creates the default inner content of the entry.
Sourceimpl OutlineEntry
impl OutlineEntry
pub fn build_inner( &self, context: Tracked<'_, Context<'_>>, span: Span, body: Content, page: Content, ) -> SourceResult<Content>
Sourcepub fn element_location(&self) -> HintedStrResult<Location>
pub fn element_location(&self) -> HintedStrResult<Location>
Returns the location of the outlined element.