pub struct FontAxis {
pub tag: Tag,
pub min: AxisValue,
pub max: AxisValue,
pub default: AxisValue,
}Expand description
A variation axis in a font.
Fields
tag: TagThe OpenType tag that identifies the axis. May be a standard tag like
wght or a custom tag.
min: AxisValueThe minimum value the font supports for this axis.
max: AxisValueThe maximum value the font supports for this axis.
default: AxisValueThe default value the font has set for this axis.