TextElem

Struct TextElem 

pub struct TextElem {
    pub text: EcoString,
}
Customizes the look and layout of text in a variety of ways.

Fields

text: EcoString

Implementations

Source

impl TextElem

pub fn new(text: EcoString) -> Self

Create a new instance of the element.

Source

impl TextElem

pub const font: Field<Self, 0u8>

pub const fallback: Field<Self, 1u8>

pub const style: Field<Self, 2u8>

pub const weight: Field<Self, 3u8>

pub const stretch: Field<Self, 4u8>

pub const size: Field<Self, 5u8>

pub const fill: Field<Self, 6u8>

pub const stroke: Field<Self, 7u8>

pub const tracking: Field<Self, 8u8>

pub const spacing: Field<Self, 9u8>

pub const cjk_latin_spacing: Field<Self, 10u8>

pub const baseline: Field<Self, 11u8>

pub const overhang: Field<Self, 12u8>

pub const top_edge: Field<Self, 13u8>

pub const bottom_edge: Field<Self, 14u8>

pub const lang: Field<Self, 15u8>

pub const region: Field<Self, 16u8>

pub const script: Field<Self, 17u8>

pub const dir: Field<Self, 18u8>

pub const hyphenate: Field<Self, 19u8>

pub const costs: Field<Self, 20u8>

pub const kerning: Field<Self, 21u8>

pub const alternates: Field<Self, 22u8>

pub const stylistic_set: Field<Self, 23u8>

pub const ligatures: Field<Self, 24u8>

pub const discretionary_ligatures: Field<Self, 25u8>

pub const historical_ligatures: Field<Self, 26u8>

pub const number_type: Field<Self, 27u8>

pub const number_width: Field<Self, 28u8>

pub const slashed_zero: Field<Self, 29u8>

pub const fractions: Field<Self, 30u8>

pub const features: Field<Self, 31u8>

pub const variations: Field<Self, 32u8>

pub const text: Field<Self, 34u8>

pub const span_offset: Field<Self, 35u8>

pub const delta: Field<Self, 36u8>

pub const emph: Field<Self, 37u8>

pub const deco: Field<Self, 38u8>

pub const case: Field<Self, 39u8>

pub const smallcaps: Field<Self, 40u8>

pub const shift_settings: Field<Self, 41u8>

Source

impl TextElem

pub fn packed(text: impl Into<EcoString>) -> Content

Creates a new text element and directly packs it into type-erased content.