Color

Enum Color 

pub enum Color {
    Process(ProcessColor),
    Spot(SpotColor),
}
A color in a specific color space.

Variants



Process(ProcessColor)

A process color.



Spot(SpotColor)

A spot color.

Implementations

Source

impl Color

pub const BLACK: Self

pub const GRAY: Self

pub const WHITE: Self

pub const SILVER: Self

pub const NAVY: Self

pub const BLUE: Self

pub const AQUA: Self

pub const TEAL: Self

pub const EASTERN: Self

pub const PURPLE: Self

pub const FUCHSIA: Self

pub const MAROON: Self

pub const RED: Self

pub const ORANGE: Self

pub const YELLOW: Self

pub const OLIVE: Self

pub const GREEN: Self

pub const LIME: Self

pub const MAP: fn() -> Module

The module of preset color maps.

pub fn luma(args: &mut Args) -> SourceResult<Color>

Create a grayscale color.

pub fn oklab(args: &mut Args) -> SourceResult<Color>

Create an #link(“https://bottosson.github.io/posts/oklab/”)Oklab color.

pub fn oklch(args: &mut Args) -> SourceResult<Color>

Create an #link(“https://bottosson.github.io/posts/oklab/”)Oklch color.

pub fn linear_rgb(args: &mut Args) -> SourceResult<Color>

Create an RGB(A) color with linear luma.

pub fn rgb(args: &mut Args) -> SourceResult<Color>

Create an RGB(A) color.

pub fn cmyk(args: &mut Args) -> SourceResult<Color>

Create a CMYK color.

pub fn hsl(args: &mut Args) -> SourceResult<Color>

Create an HSL color.

pub fn hsv(args: &mut Args) -> SourceResult<Color>

Create an HSV color.

pub fn components(&self, alpha: bool) -> Array

Extracts the components of this color.

pub fn space(&self) -> ColorSpace

Returns the constructor function for this color’s space.

pub fn to_hex(&self) -> EcoString

Returns the color’s RGB(A) hex representation (such as #ffaa32 or #020304fe).

pub fn lighten(&self, factor: Ratio) -> Color

Lightens a color by a given factor.

pub fn darken(&self, factor: Ratio) -> Color

Darkens a color by a given factor.

pub fn saturate(&self, span: Span, factor: Ratio) -> SourceResult<Color>

Increases the saturation of a color by a given factor.

pub fn desaturate(&self, span: Span, factor: Ratio) -> SourceResult<Color>

Decreases the saturation of a color by a given factor.

pub fn negate(&self, space: Smart<ColorSpace>) -> HintedStrResult<Color>

Produces the complementary color using a provided color space.

pub fn rotate( &self, span: Span, angle: Angle, space: ProcessColorSpace, ) -> SourceResult<Color>

Rotates the hue of the color by a given angle.

pub fn mix( colors: Vec<WeightedColor>, space: Smart<ColorSpace>, ) -> HintedStrResult<Color>

Create a color by mixing two or more colors.

pub fn transparentize(&self, scale: Ratio) -> StrResult<Color>

Makes a color more transparent by a given factor.

pub fn opacify(&self, scale: Ratio) -> StrResult<Color>

Makes a color more opaque by a given scale.

Source

impl Color

pub fn mix_iter( colors: impl IntoIterator<Item = WeightedColor, IntoIter = impl ExactSizeIterator<Item = WeightedColor>> + Clone, space: Smart<ColorSpace>, ) -> HintedStrResult<Color>

Same as Color::mix, but takes an iterator instead of a vector.

pub fn from_u8(r: u8, g: u8, b: u8, a: u8) -> Self

Construct a new RGBA color from 8-bit values.

pub fn from_u32(color: u32) -> Self

Converts a 32-bit integer to an RGBA color.

pub fn alpha(&self) -> Option<f32>

Returns the alpha channel of the color, if it has one.

pub fn with_alpha(self, alpha: f32) -> Self

Sets the alpha channel of the color, if it has one.

pub fn to_vec4(&self) -> [f32; 4]

Converts the color to a vec of four floats.

pub fn to_vec4_u8(&self) -> [u8; 4]

Converts the color to a vec of four u8s.

pub fn to_space(&self, space: &ColorSpace) -> HintedStrResult<Self>

pub fn to_process_space(&self, space: ProcessColorSpace) -> Self

pub fn to_luma(&self) -> Luma

pub fn to_oklab(&self) -> Oklab

pub fn to_oklch(&self) -> Oklch

pub fn to_rgb(&self) -> Rgb

pub fn to_linear_rgb(&self) -> LinearRgb

pub fn to_cmyk(&self) -> Cmyk

pub fn to_hsl(&self) -> Hsl

pub fn to_hsv(&self) -> Hsv

pub fn to_process(&self) -> ProcessColor

Convert to ProcessColor, using fallback for spot colors.

This is useful for rendering and export where spot colors cannot be expressed and need to be converted to their fallback representation.