pub enum Gradient {
Linear(Arc<LinearGradient>),
Radial(Arc<RadialGradient>),
Conic(Arc<ConicGradient>),
}Expand description
A color gradient.
Variants
Implementations
Sourceimpl Gradient
impl Gradient
Sourcepub fn linear(
args: &mut Args,
span: Span,
stops: Vec<Spanned<GradientStop>>,
space: Spanned<Smart<ColorSpace>>,
relative: Smart<RelativeTo>,
) -> SourceResult<Gradient>
pub fn linear( args: &mut Args, span: Span, stops: Vec<Spanned<GradientStop>>, space: Spanned<Smart<ColorSpace>>, relative: Smart<RelativeTo>, ) -> SourceResult<Gradient>
Creates a new linear gradient, in which colors transition along a straight line.
Sourcepub fn conic(
span: Span,
stops: Vec<Spanned<GradientStop>>,
angle: Angle,
space: Spanned<Smart<ColorSpace>>,
relative: Smart<RelativeTo>,
center: Axes<Ratio>,
) -> SourceResult<Gradient>
pub fn conic( span: Span, stops: Vec<Spanned<GradientStop>>, angle: Angle, space: Spanned<Smart<ColorSpace>>, relative: Smart<RelativeTo>, center: Axes<Ratio>, ) -> SourceResult<Gradient>
Creates a new conic gradient, in which colors change radially around a center point.
Sourcepub fn sharp(
&self,
steps: Spanned<usize>,
smoothness: Spanned<Ratio>,
) -> SourceResult<Gradient>
pub fn sharp( &self, steps: Spanned<usize>, smoothness: Spanned<Ratio>, ) -> SourceResult<Gradient>
Creates a sharp version of this gradient.
Sourcepub fn repeat(
&self,
repetitions: Spanned<usize>,
mirror: bool,
) -> SourceResult<Gradient>
pub fn repeat( &self, repetitions: Spanned<usize>, mirror: bool, ) -> SourceResult<Gradient>
Repeats this gradient a given number of times, optionally mirroring it at every second repetition.
Sourcepub fn stops(&self) -> Vec<GradientStop>
pub fn stops(&self) -> Vec<GradientStop>
Returns the stops of this gradient.
Sourcepub fn space(&self) -> ColorSpace
pub fn space(&self) -> ColorSpace
Returns the mixing space of this gradient.
Sourcepub fn relative(&self) -> Smart<RelativeTo>
pub fn relative(&self) -> Smart<RelativeTo>
Returns the relative placement of this gradient.
Sourcepub fn focal_center(&self) -> Option<Axes<Ratio>>
pub fn focal_center(&self) -> Option<Axes<Ratio>>
Returns the focal-center of this gradient.
Sourcepub fn focal_radius(&self) -> Option<Ratio>
pub fn focal_radius(&self) -> Option<Ratio>
Returns the focal-radius of this gradient.
Sourcepub fn sample(&self, t: RatioOrAngle) -> Color
pub fn sample(&self, t: RatioOrAngle) -> Color
Sample the gradient at a given position.
Sourcepub fn samples(&self, ts: Vec<RatioOrAngle>) -> Array
pub fn samples(&self, ts: Vec<RatioOrAngle>) -> Array
Samples the gradient at multiple positions at once and returns the results as an array.
Sourceimpl Gradient
impl Gradient
Sourcepub fn with_relative(self, relative: RelativeTo) -> Self
pub fn with_relative(self, relative: RelativeTo) -> Self
Clones this gradient, but with a different relative placement.
Sourcepub fn stops_ref(&self) -> &[(Color, Ratio)]
pub fn stops_ref(&self) -> &[(Color, Ratio)]
Returns a reference to the stops of this gradient.
Sourcepub fn generate_intermediate_stops_for_rgb_interpolation(
&self,
first: &GradientStop,
second: &GradientStop,
) -> impl Iterator<Item = (Color, Ratio)>
pub fn generate_intermediate_stops_for_rgb_interpolation( &self, first: &GradientStop, second: &GradientStop, ) -> impl Iterator<Item = (Color, Ratio)>
Generates additional stops to replicate a gradient in rgb color space interpolation by bisecting
Sourcepub fn sample_at(
&self,
(x, y): (f32, f32),
(width, height): (f32, f32),
) -> Color
pub fn sample_at( &self, (x, y): (f32, f32), (width, height): (f32, f32), ) -> Color
Samples the gradient at a given position, in the given container. Handles the aspect ratio and angle directly.
Sourcepub fn anti_alias(&self) -> bool
pub fn anti_alias(&self) -> bool
Does this gradient need to be anti-aliased?
Sourcepub fn unwrap_relative(&self, on_text: bool) -> RelativeTo
pub fn unwrap_relative(&self, on_text: bool) -> RelativeTo
Returns the relative placement of this gradient, handling
the special case of auto.
Sourcepub fn correct_aspect_ratio(angle: Angle, aspect_ratio: Ratio) -> Angle
pub fn correct_aspect_ratio(angle: Angle, aspect_ratio: Ratio) -> Angle
Corrects this angle for the aspect ratio of a gradient.
This is used specifically for gradients.