pub enum ProcessColor {
Luma(Luma),
Oklab(Oklab),
Oklch(Oklch),
Rgb(Rgb),
LinearRgb(LinearRgb),
Cmyk(Cmyk),
Hsl(Hsl),
Hsv(Hsv),
}Expand description
Colors with a well-defined color space.
Variants
Luma(Luma)
A 32-bit luma color.
Oklab(Oklab)
A 32-bit L*a*b* color in the Oklab color space.
Oklch(Oklch)
A 32-bit LCh color in the Oklab color space.
Rgb(Rgb)
A 32-bit RGB color.
LinearRgb(LinearRgb)
A 32-bit linear RGB color.
Cmyk(Cmyk)
A 32-bit CMYK color.
Hsl(Hsl)
A 32-bit HSL color.
Hsv(Hsv)
A 32-bit HSV color.
Implementations
Sourceimpl ProcessColor
impl ProcessColor
Sourcepub fn components(self, alpha: bool) -> Array
pub fn components(self, alpha: bool) -> Array
Extracts the components of this color.
Sourcepub fn space(self) -> ProcessColorSpace
pub fn space(self) -> ProcessColorSpace
Returns the constructor function for this color’s space.
Sourcepub fn lighten(self, factor: Ratio) -> ProcessColor
pub fn lighten(self, factor: Ratio) -> ProcessColor
Lightens a color by a given factor.
Sourcepub fn darken(self, factor: Ratio) -> ProcessColor
pub fn darken(self, factor: Ratio) -> ProcessColor
Darkens a color by a given factor.
Sourcepub fn saturate(self, span: Span, factor: Ratio) -> SourceResult<ProcessColor>
pub fn saturate(self, span: Span, factor: Ratio) -> SourceResult<ProcessColor>
Increases the saturation of a color by a given factor.
Sourcepub fn desaturate(self, span: Span, factor: Ratio) -> SourceResult<ProcessColor>
pub fn desaturate(self, span: Span, factor: Ratio) -> SourceResult<ProcessColor>
Decreases the saturation of a color by a given factor.
Sourcepub fn negate(self, space: ProcessColorSpace) -> ProcessColor
pub fn negate(self, space: ProcessColorSpace) -> ProcessColor
Produces the complementary color using a provided color space.
Sourcepub fn from_u8(r: u8, g: u8, b: u8, a: u8) -> Self
pub fn from_u8(r: u8, g: u8, b: u8, a: u8) -> Self
Construct a new RGBA color from 8-bit values.
Sourcepub fn with_alpha(self, alpha: f32) -> Self
pub fn with_alpha(self, alpha: f32) -> Self
Sets the alpha channel of the color, if it has one.
Sourcepub fn to_vec4_u8(&self) -> [u8; 4]
pub fn to_vec4_u8(&self) -> [u8; 4]
Converts the color to a vec of four u8s.
pub fn to_space(&self, space: ProcessColorSpace) -> Self
pub fn to_luma(self) -> Luma
pub fn to_oklab(self) -> Oklab
pub fn to_oklch(self) -> Oklch
pub fn to_rgb(self) -> Rgb
pub fn to_linear_rgb(self) -> LinearRgb
pub fn to_cmyk(self) -> Cmyk
pub fn to_hsl(self) -> Hsl
pub fn to_hsv(self) -> Hsv