pub struct Dict(/* private fields */);Expand description
A map from string keys to values.
Implementations
Sourceimpl Dict
impl Dict
Sourcepub fn at_mut(&mut self, key: &str) -> HintedStrResult<&mut Value>
pub fn at_mut(&mut self, key: &str) -> HintedStrResult<&mut Value>
Mutably borrow the value the given key maps to.
Sourcepub fn take(&mut self, key: &str) -> StrResult<Value>
pub fn take(&mut self, key: &str) -> StrResult<Value>
Remove the value if the dictionary contains the given key.
Sourcepub fn iter(&self) -> Iter<'_, Str, Value>
pub fn iter(&self) -> Iter<'_, Str, Value>
Iterate over pairs of references to the contained keys and values.
Sourcepub fn finish(&self, expected: &[&str]) -> StrResult<()>
pub fn finish(&self, expected: &[&str]) -> StrResult<()>
Check if there is any remaining pair, and if so return an “unexpected key” error.
pub fn unexpected_keys( unexpected: Vec<&str>, hint_expected: Option<&[&str]>, ) -> EcoString
Sourceimpl Dict
impl Dict
Sourcepub fn at(&self, key: Str, default: Option<Value>) -> StrResult<Value>
pub fn at(&self, key: Str, default: Option<Value>) -> StrResult<Value>
Returns the value associated with the specified key in the dictionary.
Sourcepub fn remove(&mut self, key: Str, default: Option<Value>) -> StrResult<Value>
pub fn remove(&mut self, key: Str, default: Option<Value>) -> StrResult<Value>
Removes a pair from the dictionary by key and return the value.
Sourcepub fn values(&self) -> Array
pub fn values(&self) -> Array
Returns the values of the dictionary as an array in insertion order.
Sourcepub fn pairs(&self) -> Array
pub fn pairs(&self) -> Array
Returns the keys and values of the dictionary as an array of pairs.