pub trait Chainable {
// Required method
fn chain<'a>(&'a self, outer: &'a StyleChain<'_>) -> StyleChain<'a>;
}Expand description
Things that can be attached to a style chain.
Required Methods
Sourcefn chain<'a>(&'a self, outer: &'a StyleChain<'_>) -> StyleChain<'a>
fn chain<'a>(&'a self, outer: &'a StyleChain<'_>) -> StyleChain<'a>
Attach self as the first link of the chain.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".