pub struct FencedItem<'a> {
pub open: Option<MathItem<'a>>,
pub close: Option<MathItem<'a>>,
pub body: FencedBody<'a>,
pub balanced: bool,
}Expand description
An item enclosed in delimiters.
Fields
open: Option<MathItem<'a>>The optional opening delimiter.
close: Option<MathItem<'a>>The optional closing delimiter.
body: FencedBody<'a>The item between the delimiters.
balanced: boolHow the target height for the delimiters should be calculated.
If true, the height for each body item is two times the maximum of its ascent and descent. If false, the height for each body item is simply its height.
Only used in paged export.