Structuring elements that define the document model.
Structs
- Anchor
Generator - Creates unique IDs for elements.
- Asset
Data - The raw data for an asset.
- Asset
Elem - Adds a custom file to a bundle.
- Author
- A list of authors.
- Bibliography
- A loaded bibliography.
- Bibliography
Elem - A bibliography / reference listing.
- Cite
Elem - Cite a work from the bibliography.
- Cite
Group - A group of consecutive citations.
- CslIndent
Elem - Translation of
display="indent"in CSL. - CslLight
Elem - Translation of
font-weight="light"in CSL. - CslStyle
- A loaded CSL style.
- Direct
Link Elem - This is a temporary hack to dispatch to - a raw link that does not go through
LinkElemin paged -LinkElemin HTML (there is no equivalent to a direct link) - Divider
Elem - A thematic break that separates sections of content.
- Document
Elem - Manages metadata and is used to add a document file to a bundle.
- Document
Info - Details about the document.
- Early
Link Resolver - Resolves location links during compilation.
- Emph
Elem - Emphasizes content by toggling italics.
- Enum
Elem - A numbered list.
- Enum
Item - An enumeration item.
- Figure
Caption - The caption of a figure.
- Figure
Elem - A figure with an optional caption.
- First
Line Indent - Configuration for first line indent.
- Footnote
Container - In HTML export, this is inserted at the end of the body to display footnotes.
- Footnote
Elem - A footnote.
- Footnote
Entry - An entry in a footnote list.
- Footnote
Marker - This is an empty element inserted by the HTML footnote rule to indicate the presence of the default footnote rule.
- Heading
Elem - A section heading.
- Justification
Limits - Configures how justification may distribute spacing.
- Keywords
- A list of keywords.
- Late
Link Resolver - Resolves location links during export.
- Limits
- Determines the minimum and maximum size by or to which spacing may be shrunk and stretched.
- Link
Elem - Links to a URL or a location in the document.
- Link
Marker - An element that wraps all content that is @Content::linked to a destination.
- List
Elem - A bullet list.
- List
Item - A bullet list item.
- Numbering
Pattern - How to turn a number into text.
- Outline
Elem - A table of contents, figures, or other elements.
- Outline
Entry - Represents an entry line in an outline.
- Outline
Node - A node in a tree of outline entry.
- ParElem
- A logical subdivison of textual content.
- ParLine
- A paragraph line.
- ParLine
Marker - A marker used to indicate the presence of a line.
- Parbreak
Elem - A paragraph break.
- Quote
Elem - Displays a quote alongside an optional attribution.
- RefElem
- A reference to a label or bibliography.
- Rendered
Bibliography - The rendered parts for a bibliography.
- Rendered
Entry - The rendered parts for a bibliography entry.
- Strong
Elem - Strongly emphasizes content by increasing the font weight.
- Table
Cell - A cell in the table.
- Table
Elem - A table of items.
- Table
Footer - A repeatable table footer.
- TableH
Line - A horizontal line in the table.
- Table
Header - A repeatable table header.
- TableV
Line - A vertical line in the table.
- Telephone
- Term
Item - A term list item.
- Terms
Elem - A list of terms and their descriptions.
- Title
Elem - A document title.
- Url
- A uniform resource locator with a maximum length.
- Works
- Fully formatted citations and references, generated once (through memoization) for the whole document. This setup is necessary because citation formatting is inherently stateful and we need access to all citations to do it. Fully formatted citation groups and bibliographies, generated once (through memoization) for the whole document.
Enums
- Attribution
- Attribution for a quote.
- Citation
Form - The form of the citation.
- CslSource
- Source for a CSL style.
- Destination
- A link destination.
- Document
Format - Supported export formats for bundle documents.
- Figure
Kind - The
kindparameter of aFigureElem. - Footnote
Body - The body of a footnote can be either some content or a label referencing another footnote.
- Line
Numbering Scope - Possible line numbering scope options, indicating how often the line number counter should be reset.
- Linebreaks
- How to determine line breaks in a paragraph.
- Link
Target - A target where a link can go.
- List
Marker - A list’s marker.
- Numbering
- How to number a sequence of things.
- Outline
Indent - Defines how an outline is indented.
- Paged
Format - Supported paged export formats for bundle documents.
- RefForm
- The form of the reference.
- Resolved
Link - A resolved internal link.
- Supplement
- Additional content for a reference.
- Table
Child - Any child of a table element.
- Table
Item - A table item, which is the basic unit of table specification.
- UrlContact
Scheme
Constants
Traits
- Document
- A document resulting from compilation.
- Figurable
- An element that can be auto-detected in a figure.
- List
Item Like - A list item, enum item, or term list item.
- List
Like - A list, enum, or term list.
- Outlinable
- Marks an element as being able to be outlined.
- Refable
- Marks an element as being able to be referenced. This is used to implement
the
@refelement.