pub enum Color {
Process(ProcessColor),
Spot(SpotColor),
}Expand description
A color in a specific color space.
Variants
Implementations
Sourceimpl Color
impl Color
pub const BLACK: Self
pub const GRAY: Self
pub const WHITE: Self
pub const SILVER: Self
pub const NAVY: Self
pub const BLUE: Self
pub const AQUA: Self
pub const TEAL: Self
pub const EASTERN: Self
pub const PURPLE: Self
pub const FUCHSIA: Self
pub const MAROON: Self
pub const RED: Self
pub const ORANGE: Self
pub const YELLOW: Self
pub const OLIVE: Self
pub const GREEN: Self
pub const LIME: Self
Sourcepub fn luma(args: &mut Args) -> SourceResult<Color>
pub fn luma(args: &mut Args) -> SourceResult<Color>
Create a grayscale color.
Sourcepub fn oklab(args: &mut Args) -> SourceResult<Color>
pub fn oklab(args: &mut Args) -> SourceResult<Color>
Create an #link(“https://bottosson.github.io/posts/oklab/”)Oklab color.
Sourcepub fn oklch(args: &mut Args) -> SourceResult<Color>
pub fn oklch(args: &mut Args) -> SourceResult<Color>
Create an #link(“https://bottosson.github.io/posts/oklab/”)Oklch color.
Sourcepub fn linear_rgb(args: &mut Args) -> SourceResult<Color>
pub fn linear_rgb(args: &mut Args) -> SourceResult<Color>
Create an RGB(A) color with linear luma.
Sourcepub fn rgb(args: &mut Args) -> SourceResult<Color>
pub fn rgb(args: &mut Args) -> SourceResult<Color>
Create an RGB(A) color.
Sourcepub fn cmyk(args: &mut Args) -> SourceResult<Color>
pub fn cmyk(args: &mut Args) -> SourceResult<Color>
Create a CMYK color.
Sourcepub fn hsl(args: &mut Args) -> SourceResult<Color>
pub fn hsl(args: &mut Args) -> SourceResult<Color>
Create an HSL color.
Sourcepub fn hsv(args: &mut Args) -> SourceResult<Color>
pub fn hsv(args: &mut Args) -> SourceResult<Color>
Create an HSV color.
Sourcepub fn components(&self, alpha: bool) -> Array
pub fn components(&self, alpha: bool) -> Array
Extracts the components of this color.
Sourcepub fn space(&self) -> ColorSpace
pub fn space(&self) -> ColorSpace
Returns the constructor function for this color’s space.
Sourcepub fn to_hex(&self) -> EcoString
pub fn to_hex(&self) -> EcoString
Returns the color’s RGB(A) hex representation (such as #ffaa32 or #020304fe).
Sourcepub fn saturate(&self, span: Span, factor: Ratio) -> SourceResult<Color>
pub fn saturate(&self, span: Span, factor: Ratio) -> SourceResult<Color>
Increases the saturation of a color by a given factor.
Sourcepub fn desaturate(&self, span: Span, factor: Ratio) -> SourceResult<Color>
pub fn desaturate(&self, span: Span, factor: Ratio) -> SourceResult<Color>
Decreases the saturation of a color by a given factor.
Sourcepub fn negate(&self, space: Smart<ColorSpace>) -> HintedStrResult<Color>
pub fn negate(&self, space: Smart<ColorSpace>) -> HintedStrResult<Color>
Produces the complementary color using a provided color space.
Sourcepub fn rotate(
&self,
span: Span,
angle: Angle,
space: ProcessColorSpace,
) -> SourceResult<Color>
pub fn rotate( &self, span: Span, angle: Angle, space: ProcessColorSpace, ) -> SourceResult<Color>
Rotates the hue of the color by a given angle.
Sourcepub fn mix(
colors: Vec<WeightedColor>,
space: Smart<ColorSpace>,
) -> HintedStrResult<Color>
pub fn mix( colors: Vec<WeightedColor>, space: Smart<ColorSpace>, ) -> HintedStrResult<Color>
Create a color by mixing two or more colors.
Sourcepub fn transparentize(&self, scale: Ratio) -> StrResult<Color>
pub fn transparentize(&self, scale: Ratio) -> StrResult<Color>
Makes a color more transparent by a given factor.
Sourceimpl Color
impl Color
Sourcepub fn mix_iter(
colors: impl IntoIterator<Item = WeightedColor, IntoIter = impl ExactSizeIterator<Item = WeightedColor>> + Clone,
space: Smart<ColorSpace>,
) -> HintedStrResult<Color>
pub fn mix_iter( colors: impl IntoIterator<Item = WeightedColor, IntoIter = impl ExactSizeIterator<Item = WeightedColor>> + Clone, space: Smart<ColorSpace>, ) -> HintedStrResult<Color>
Same as Color::mix, but takes an iterator instead of a vector.
Sourcepub fn from_u8(r: u8, g: u8, b: u8, a: u8) -> Self
pub fn from_u8(r: u8, g: u8, b: u8, a: u8) -> Self
Construct a new RGBA color from 8-bit values.
Sourcepub fn with_alpha(self, alpha: f32) -> Self
pub fn with_alpha(self, alpha: f32) -> Self
Sets the alpha channel of the color, if it has one.
Sourcepub fn to_vec4_u8(&self) -> [u8; 4]
pub fn to_vec4_u8(&self) -> [u8; 4]
Converts the color to a vec of four u8s.
pub fn to_space(&self, space: &ColorSpace) -> HintedStrResult<Self>
pub fn to_process_space(&self, space: ProcessColorSpace) -> Self
pub fn to_luma(&self) -> Luma
pub fn to_oklab(&self) -> Oklab
pub fn to_oklch(&self) -> Oklch
pub fn to_rgb(&self) -> Rgb
pub fn to_linear_rgb(&self) -> LinearRgb
pub fn to_cmyk(&self) -> Cmyk
pub fn to_hsl(&self) -> Hsl
pub fn to_hsv(&self) -> Hsv
Sourcepub fn to_process(&self) -> ProcessColor
pub fn to_process(&self) -> ProcessColor
Convert to ProcessColor, using fallback for spot colors.
This is useful for rendering and export where spot colors cannot be expressed and need to be converted to their fallback representation.